cosinnus.formats package
========================

Subpackages
-----------

.. toctree::

    cosinnus.formats.de
    cosinnus.formats.en

Module contents
---------------

.. automodule:: cosinnus.formats
    :members:
    :undoc-members:
    :show-inheritance:
